Generatable

Trait Generatable 

pub trait Generatable {
    // Required method
    fn generate<C>(&self, context: &mut C) -> Result<(), Error>
       where C: Context;
}
ABI data structure that can be generated into arbitrary programming language supported by Ethbind.

Ethbind provides Generatable implementations for types of crate ethbind-json

Required Methods

fn generate<C>(&self, context: &mut C) -> Result<(), Error>
where C: Context,

Generate abi data to Target programming language code.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Generatable for Vec<AbiField>

Source

fn generate<C>(&self, context: &mut C) -> Result<(), Error>
where C: Context,

Implementors